@@ -1,5 +1,6 @@
 from typing import (
-    Tuple,
+    # Dict,
+    Any, Callable, Tuple,
     Type,
     Union,
     List,
@@ -15,23 +16,35 @@ from pandas.core.generic import NDFrame
 
 import numpy as np
 
-from .directive import parse
+from .directive import (
+    parse,
+    Directive,
+    DirectiveCache
+)
 
 from .common import (
     meta_property,
     copy_stock_metas,
     ensure_return_type,
+    rolling_calc,
 
     KEY_ALIAS_MAP,
     KEY_COLUMNS_INFO_MAP,
-    KEY_DIRECTIVES_CACHE,
-
-    DirectiveCache
+    KEY_DIRECTIVES_CACHE
 )
 
 
 class ColumnInfo:
-    def __init__(self, size, directive, period) -> None:
+    size: int
+    directive: Directive
+    period: int
+
+    def __init__(
+        self,
+        size: int,
+        directive: Directive,
+        period: int
+    ) -> None:
         self.size = size
         self.directive = directive
         self.period = period
@@ -46,6 +59,9 @@ class ColumnInfo:
             self.period
         )
 
+    def __repr__(self) -> str:
+        return f'<ColumnInfo {self.directive}, size:{self.size}, period:{self.period}>'  # noqa: E501
+
 
 class StockDataFrame(DataFrame):
     """The wrapper class for `pandas.DataFrame`
@@ -55,6 +71,10 @@ class StockDataFrame(DataFrame):
 
     _create_column: bool
 
+    # _stock_aliases_map: Dict[str]
+    # _stock_columns_info_map: Dict[ColumnInfo]
+    # _stock_directives_cache: DirectiveCache
+
     _stock_aliases_map = meta_property(
         KEY_ALIAS_MAP, lambda: {}
     )
@@ -67,8 +87,11 @@ class StockDataFrame(DataFrame):
         KEY_DIRECTIVES_CACHE, lambda: DirectiveCache()
     )
 
+    # Methods that used by pandas and sub classes
+    # --------------------------------------------------------------------
+
     @property
-    def _constructor(self) -> Type['StockDataFrame']:
+    def _constructor(_) -> Type['StockDataFrame']:
         """This method overrides `DataFrame._constructor`
         which ensures the return type of several DataFrame methods
         """
@@ -136,6 +159,9 @@ class StockDataFrame(DataFrame):
 
         return result
 
+    # Public Methods of stock-pandas
+    # --------------------------------------------------------------------
+
     def get_column(self, key: str) -> Series:
         """Gets the column directly from dataframe by key.
 
@@ -197,7 +223,11 @@ class StockDataFrame(DataFrame):
 
         return series
 
-    def alias(self, as_name, src_name) -> None:
+    def alias(
+        self,
+        as_name: str,
+        src_name: str
+    ) -> None:
         """Defines column alias or directive alias
 
         Args:
@@ -216,6 +246,56 @@ class StockDataFrame(DataFrame):
 
         self._stock_aliases_map[as_name] = src_name
 
+    def directive_stringify(
+        self,
+        directive_str: str
+    ) -> str:
+        """Stringify a `Directive` and get its full name
+        which is the actual column of the dataframe
+
+        Usage::
+            stock.directive_stringify('boll')
+
+            # It gets "boll:20,close"
+        """
+
+        return str(self._parse_directive(directive_str))
+
+    def rolling_calc(
+        self,
+        size: int,
+        on: str,
+        apply: Callable[[np.ndarray], Any],
+        forward: bool = False,
+        fill=np.nan
+    ) -> np.ndarray:
+        """Apply a 1-D function along the given column `on`
+
+        Args:
+            size (int): the size of the rolling window
+            on (str | Directive): along which the function should be applied
+            apply (Callable): the 1-D function to apply
+            forward (:obj:`bool`, optional): whether we should look backward
+                (default value) to get each rolling window or not
+            fill (:obj:`any`): the value used to fill where there are
+                not enough items to form a rolling window
+        """
+
+        array = self[on].to_numpy()
+
+        *_, stride = array.strides
+
+        return rolling_calc(
+            array,
+            size,
+            apply,
+            fill,
+            stride,
+            not forward
+        )
+
+    # --------------------------------------------------------------------
+
     def _map_keys(self, keys) -> List:
         return [
             self._map_single_key(key)
@@ -249,12 +329,15 @@ class StockDataFrame(DataFrame):
         #   So `pandas.DataFrame.__getitem__` could index the right column
         return column_name
 
-    def _parse_directive(self, directive_str: str):
+    def _parse_directive(
+        self,
+        directive_str: str
+    ) -> Directive:
         return parse(directive_str, self._stock_directives_cache)
 
     def _get_or_calc_series(
         self,
-        directive,
+        directive: Directive,
         create_column: bool
     ) -> Tuple[str, np.ndarray]:
         """Gets the series column corresponds the `directive` or
